<?php
/**
 * Kids Education Pro Category Blog Customizer options
 *
 * @package Theme Palace
 * @subpackage kids education pro
 * @since Kids Education Pro 1.0
 */


// Add category blog enable section
$wp_customize->add_section( 'kids_education_pro_category_blog_section', array(
	'title'             => __('Category Blog','kids-education-pro'),
	'description'       => __( 'Category Blog section options.', 'kids-education-pro' ),
	'panel'             => 'kids_education_pro_sections_panel'
) );

// Add category blog enable setting and control.
$wp_customize->add_setting( 'kids_education_pro_theme_options[category_blog_enable]', array(
	'default'           => $options['category_blog_enable'],
	'sanitize_callback' => 'kids_education_pro_sanitize_select'
) );

$wp_customize->add_control( 'kids_education_pro_theme_options[category_blog_enable]', array(
	'label'             => __( 'Enable on', 'kids-education-pro' ),
	'section'           => 'kids_education_pro_category_blog_section',
	'type'              => 'select',
	'choices'           => kids_education_pro_enable_disable_options()
) );

// Add features content layout setting and control.
$wp_customize->add_setting( 'kids_education_pro_theme_options[category_blog_section_layout]', array(
	'default'           => $options['category_blog_section_layout'],
	'sanitize_callback' => 'kids_education_pro_sanitize_select'
) );

$wp_customize->add_control( 'kids_education_pro_theme_options[category_blog_section_layout]', array(
	'label'           	=> __( 'Select Layout', 'kids-education-pro' ),
	'section'         	=> 'kids_education_pro_category_blog_section',
	'type'            	=> 'select',
	'active_callback' 	=> 'kids_education_pro_is_category_blog_section_active',
	'choices'         	=> array(
		'two-columns'	=> __( 'Two Columns', 'kids-education-pro'),
		'three-columns'	=> __( 'Three Columns', 'kids-education-pro'),
	)
) );

// Add category blog content type setting and control.
$wp_customize->add_setting( 'kids_education_pro_theme_options[category_blog_content_type]', array(
	'default'           => $options['category_blog_content_type'],
	'sanitize_callback' => 'kids_education_pro_sanitize_select'
) );

$wp_customize->add_control( 'kids_education_pro_theme_options[category_blog_content_type]', array(
	'label'           	=> __( 'Content Type', 'kids-education-pro' ),
	'section'         	=> 'kids_education_pro_category_blog_section',
	'type'            	=> 'select',
	'active_callback' 	=> 'kids_education_pro_is_category_blog_section_active',
	'choices'         	=> array(
		'demo'       	=> __( 'Demo', 'kids-education-pro' ),
		'category'    	=> __( 'Category', 'kids-education-pro' )
	)
) );


// Add category blog title setting and control.
$wp_customize->add_setting( 'kids_education_pro_theme_options[category_blog_title]', array(
	'default'           => $options['category_blog_title'],
	'transport'         => 'postMessage',
	'sanitize_callback' => 'sanitize_text_field'
) );

$wp_customize->add_control( 'kids_education_pro_theme_options[category_blog_title]', array(
	'label'           	=> __( 'Title', 'kids-education-pro' ),
	'section'         	=> 'kids_education_pro_category_blog_section',
	'type'            	=> 'text',
	'active_callback' 	=> 'kids_education_pro_is_category_blog_content_demo_inactive',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
	$wp_customize->selective_refresh->add_partial( 'kids_education_pro_theme_options[category_blog_title]', array(
		'selector'            => '#blog h2.entry-title',
		'render_callback'     => 'kids_education_pro_customize_partial_category_blog_title',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
	) );
}

// Add category blog description setting and control.
$wp_customize->add_setting( 'kids_education_pro_theme_options[category_blog_description]', array(
	'default'           => $options['category_blog_description'],
	'transport'         => 'postMessage',
	'sanitize_callback' => 'esc_textarea'
) );

$wp_customize->add_control( 'kids_education_pro_theme_options[category_blog_description]', array(
	'label'           		=> __( 'Description', 'kids-education-pro' ),
	'section'         		=> 'kids_education_pro_category_blog_section',
	'type'            		=> 'textarea',
	'active_callback' 		=> 'kids_education_pro_is_category_blog_content_demo_inactive',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
	$wp_customize->selective_refresh->add_partial( 'kids_education_pro_theme_options[category_blog_description]', array(
		'selector'            => '#blog p.sub-title',
		'render_callback'     => 'kids_education_pro_customize_partial_category_blog_description',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
	) );
}

// Add category blog number setting and control.
$wp_customize->add_setting( 'kids_education_pro_theme_options[category_blog_count]', array(
	'default'           => $options['category_blog_count'],
	'sanitize_callback' => 'kids_education_pro_sanitize_number_range',
	'validate_callback' => 'kids_education_pro_validate_no_of_blog'
) );

$wp_customize->add_control( 'kids_education_pro_theme_options[category_blog_count]', array(
	'label'           => __( 'Number of posts.', 'kids-education-pro' ),
	'description'     => __( 'Notice: Please refresh after the number of slides is set to see the effects.', 'kids-education-pro' ),
	'section'         => 'kids_education_pro_category_blog_section',
	'type'            => 'number',
	'active_callback' => 'kids_education_pro_is_category_blog_content_demo_inactive',
	'input_attrs'     => array(
		'max' 		  => 6,
		'min' 		  => 1
	)
) );

/**
 * Content type: Catgory
*/

// Show category type setting and control
$wp_customize->add_setting( 'kids_education_pro_theme_options[category_blog_content_category]', array(
	'sanitize_callback' => 'kids_education_pro_sanitize_category_list'
) );

$wp_customize->add_control( new Kids_Education_Pro_Dropdown_Category_Control( $wp_customize, 'kids_education_pro_theme_options[category_blog_content_category]', array(
	'label'           => __( 'Category', 'kids-education-pro' ),
	'description'     => __( 'Select the category of posts to be shown.', 'kids-education-pro' ),
	'section'         => 'kids_education_pro_category_blog_section',
	'active_callback' => 'kids_education_pro_is_category_blog_content_demo_inactive',
) ) );

// Add background property setting and control.
$wp_customize->add_setting( 'kids_education_pro_theme_options[category_blog_background_property]', array(
	'default'           => $options['category_blog_background_property'],
	'sanitize_callback' => 'kids_education_pro_sanitize_select'
) );

$wp_customize->add_control( 'kids_education_pro_theme_options[category_blog_background_property]', array(
	'label'           	=> __( 'Select background property', 'kids-education-pro' ),
	'section'         	=> 'kids_education_pro_category_blog_section',
	'active_callback' 	=> 'kids_education_pro_is_category_blog_content_demo_inactive',
	'type'				=> 'select',
	'choices'			=> array(
		'background_image' => __( 'Background Image', 'kids-education-pro' ),
		'background_color' => __( 'Background Color', 'kids-education-pro' ), 
	)
) );

// Add background image setting and control.
$wp_customize->add_setting( 'kids_education_pro_theme_options[category_blog_background_image]', array(
	'default'           => $options['category_blog_background_image'],
	'sanitize_callback' => 'esc_url_raw'
) );

$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'kids_education_pro_theme_options[category_blog_background_image]',
    array(
		'label'           => __( 'Upload a background image', 'kids-education-pro' ),
		'description'     => __( 'Recommended background image size is 1949x2561 px', 'kids-education-pro' ),
		'section'         => 'kids_education_pro_category_blog_section',
		'active_callback' => 'kids_education_pro_is_category_blog_background_property_image',
   )
));

// Add background color setting and control.
$wp_customize->add_setting( 'kids_education_pro_theme_options[category_blog_background_color]', array(
	'default'           => $options['category_blog_background_color'],
	'sanitize_callback' => 'sanitize_hex_color'
) );

$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'kids_education_pro_theme_options[category_blog_background_color]', array(
	'label'        => __( 'Background Color', 'kids-education-pro' ),
	'section'    => 'kids_education_pro_category_blog_section',
	'active_callback' => 'kids_education_pro_is_category_blog_background_property_color',
) ) );