<?php
/**
 * Gallery Customizer options
 *
 * @package Theme Palace
 * @subpackage kids education pro
 * @since Kids Education Pro 1.0
 */

// Add gallery enable section
$wp_customize->add_section( 'kids_education_pro_gallery_section', array(
	'title'             => __('Gallery','kids-education-pro'),
	'panel'             => 'kids_education_pro_sections_panel'
) );

// Add gallery enable setting and control.
$wp_customize->add_setting( 'kids_education_pro_theme_options[gallery_enable]', array(
	'default'           => $options['gallery_enable'],
	'sanitize_callback' => 'kids_education_pro_sanitize_select'
) );

$wp_customize->add_control( 'kids_education_pro_theme_options[gallery_enable]', array(
	'label'             => __( 'Enable on', 'kids-education-pro' ),
	'section'           => 'kids_education_pro_gallery_section',
	'type'              => 'select',
	'choices'           => kids_education_pro_enable_disable_options()
) );

// Add photo gallery source
$wp_customize->add_setting( 'kids_education_pro_theme_options[gallery_source]', array(
	'default'           => $options['gallery_source'],
	'sanitize_callback' => 'kids_education_pro_sanitize_select'
) );

$wp_customize->add_control( 'kids_education_pro_theme_options[gallery_source]', array(
	'label'             => __( 'Gallery Source', 'kids-education-pro' ),
	'section'           => 'kids_education_pro_gallery_section',
	'type'              => 'select',
	'choices'           => array(
		'demo'			=> __( 'Demo', 'kids-education-pro' ),
		'category'		=> __( 'Category', 'kids-education-pro' )
	),
	'active_callback' => 'kids_education_pro_is_gallery_active', 
) );


// Add gallery title setting and control.
$wp_customize->add_setting( 'kids_education_pro_theme_options[gallery_title]', array(
	'default'           => $options['gallery_title'],
	'sanitize_callback' => 'sanitize_text_field',
	'transport'         => 'postMessage',
) );

$wp_customize->add_control( 'kids_education_pro_theme_options[gallery_title]', array(
	'label'           => __( 'Title', 'kids-education-pro' ),
	'section'         => 'kids_education_pro_gallery_section',
	'type'            => 'text',
	'active_callback' => 'kids_education_pro_gallery_source_demo_inactive',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
	$wp_customize->selective_refresh->add_partial( 'kids_education_pro_theme_options[gallery_title]', array(
		'selector'            => '#portfolio-gallery h2.entry-title',
		'render_callback'     => 'kids_education_pro_customize_partial_gallery_title',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
	) );
}

// Add gallery title setting and control.
$wp_customize->add_setting( 'kids_education_pro_theme_options[gallery_description]', array(
	'default'           => $options['gallery_description'],
	'sanitize_callback' => 'esc_textarea',
	'transport'         => 'postMessage',
) );

$wp_customize->add_control( 'kids_education_pro_theme_options[gallery_description]', array(
	'label'           => __( 'Short Description', 'kids-education-pro' ),
	'section'         => 'kids_education_pro_gallery_section',
	'type'            => 'textarea',
	'active_callback' => 'kids_education_pro_gallery_source_demo_inactive',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
	$wp_customize->selective_refresh->add_partial( 'kids_education_pro_theme_options[gallery_description]', array(
		'selector'            => '#portfolio-gallery p.sub-title',
		'render_callback'     => 'kids_education_pro_customize_partial_gallery_description',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
	) );
}

// no of images in gallery.
$wp_customize->add_setting( 'kids_education_pro_theme_options[gallery_no_of_img]', array(
	'default'           => $options['gallery_no_of_img'],
	'sanitize_callback' => 'kids_education_pro_sanitize_number_range',
	'validate_callback' => 'kids_education_pro_validate_no_of_gallery'
) );

$wp_customize->add_control( 'kids_education_pro_theme_options[gallery_no_of_img]', array(
	'label'             => __( 'No of Images', 'kids-education-pro' ),
	'section'           => 'kids_education_pro_gallery_section',
	'type'              => 'number',
	'input_attrs'		=> array(
		'min'          	=> 1,
		'max' 			=> 12,
		'style'        	=> 'width: 80px;'
	),
	'active_callback' 	=> 'kids_education_pro_gallery_source_demo_inactive', 
) );

// Add gallery content type setting and control.
$wp_customize->add_setting( 'kids_education_pro_theme_options[gallery_category]', array(
	'sanitize_callback' => 'kids_education_pro_sanitize_category_list'
) );

$wp_customize->add_control( new Kids_Education_Pro_Dropdown_Category_Control( $wp_customize, 'kids_education_pro_theme_options[gallery_category]', array(
	'label'           => __( 'Select categories', 'kids-education-pro' ),
	'section'         => 'kids_education_pro_gallery_section',
	'type'            => 'dropdown-categories',
	'active_callback' => 'kids_education_pro_gallery_source_demo_inactive', 
) ) );

// Load more text 
$wp_customize->add_setting( 'kids_education_pro_theme_options[gallery_page_readmore]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'         	=> $options['gallery_page_readmore'],
) );

$wp_customize->add_control( 'kids_education_pro_theme_options[gallery_page_readmore]', array(
	'label'           => __( 'Read more', 'kids-education-pro' ),
	'description'	  => __( 'Leave empty to hide readmore button', 'kids-education-pro' ),
	'section'         => 'kids_education_pro_gallery_section',
	'active_callback' => 'kids_education_pro_gallery_source_demo_inactive', 
) );

// page link
$wp_customize->add_setting( 'kids_education_pro_theme_options[gallery_page_link]', array(
	'sanitize_callback' => 'absint',
) );

$wp_customize->add_control( 'kids_education_pro_theme_options[gallery_page_link]', array(
	'label'           => __( 'Link Gallery Page', 'kids-education-pro' ),
	'section'         => 'kids_education_pro_gallery_section',
	'type'            => 'dropdown-pages',
	'active_callback' => 'kids_education_pro_gallery_source_demo_inactive', 
) );

// Add background property setting and control.
$wp_customize->add_setting( 'kids_education_pro_theme_options[gallery_background_property]', array(
	'default'           => $options['gallery_background_property'],
	'sanitize_callback' => 'kids_education_pro_sanitize_select'
) );

$wp_customize->add_control( 'kids_education_pro_theme_options[gallery_background_property]', array(
	'label'           	=> __( 'Select background property', 'kids-education-pro' ),
	'section'         	=> 'kids_education_pro_gallery_section',
	'active_callback' 	=> 'kids_education_pro_gallery_source_demo_inactive',
	'type'				=> 'select',
	'choices'			=> array(
		'background_image' => __( 'Background Image', 'kids-education-pro' ),
		'background_color' => __( 'Background Color', 'kids-education-pro' ), 
	)
) );

// Add background image setting and control.
$wp_customize->add_setting( 'kids_education_pro_theme_options[gallery_background_image]', array(
	'default'           => $options['gallery_background_image'],
	'sanitize_callback' => 'esc_url_raw'
) );

$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'kids_education_pro_theme_options[gallery_background_image]',
    array(
		'label'           => __( 'Upload a background image', 'kids-education-pro' ),
		'description'     => __( 'Recommended background image size is 1920x420 px', 'kids-education-pro' ),
		'section'         => 'kids_education_pro_gallery_section',
		'active_callback' => 'kids_education_pro_is_gallery_background_property_image',
   )
));

// Add background color setting and control.
$wp_customize->add_setting( 'kids_education_pro_theme_options[gallery_background_color]', array(
	'default'           => $options['gallery_background_color'],
	'sanitize_callback' => 'sanitize_hex_color'
) );

$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'kids_education_pro_theme_options[gallery_background_color]', array(
	'label'        => __( 'Background Color', 'kids-education-pro' ),
	'section'    => 'kids_education_pro_gallery_section',
	'active_callback' => 'kids_education_pro_is_gallery_background_property_color',
) ) );