<?php
/**
 * Info content Customizer options
 *
 * @package Theme Palace
 * @subpackage Kids Education Pro
 * @since Kids Education Pro 1.0
 */


// Add Info content enable section
$wp_customize->add_section( 'kids_education_pro_info_content_section', array(
	'title'             => __( 'Info Content','kids-education-pro'),
	'description'       => __( 'Info content section options.', 'kids-education-pro' ),
	'priority'			=> '10',
	'panel'             => 'kids_education_pro_sections_panel'
) );

// Add Info content enable setting and control.
$wp_customize->add_setting( 'kids_education_pro_theme_options[enable_info_content]', array(
	'default'           => $options['enable_info_content'],
	'sanitize_callback' => 'kids_education_pro_sanitize_select'
) );

$wp_customize->add_control( 'kids_education_pro_theme_options[enable_info_content]', array(
	'label'             => __( 'Check To Enable', 'kids-education-pro' ),
	'section'           => 'kids_education_pro_info_content_section',
	'type'              => 'select',
	'choices'			=> kids_education_pro_enable_disable_options(),
) );

// Add Info content type setting and control.
$wp_customize->add_setting( 'kids_education_pro_theme_options[info_content_type]', array(
	'default'           => $options['info_content_type'],
	'sanitize_callback' => 'kids_education_pro_sanitize_select'
) );

$wp_customize->add_control( 'kids_education_pro_theme_options[info_content_type]', array(
	'label'           	=> __( 'Content Type', 'kids-education-pro' ),
	'section'         	=> 'kids_education_pro_info_content_section',
	'type'            	=> 'select',
	'active_callback' 	=> 'kids_education_pro_is_info_content_active',
	'choices'         	=> array(
		'demo'			=> __( 'Demo','kids-education-pro'),
		'page'			=> __( 'Page', 'kids-education-pro'),
	)
) );

// Select page from info content section
$wp_customize->add_setting( 'kids_education_pro_theme_options[info_content_page_id]', array(
	'sanitize_callback' => 'kids_education_pro_sanitize_page'
) );

$wp_customize->add_control( 'kids_education_pro_theme_options[info_content_page_id]', array(
	'label'             => __( 'Select Page' , 'kids-education-pro' ),
	'section'           => 'kids_education_pro_info_content_section',
	'active_callback'	=> 'kids_education_pro_is_info_content_as_page',
	'type'              => 'dropdown-pages',
) );

// Add heading type setting and control.
$wp_customize->add_setting( 'kids_education_pro_theme_options[info_content_heading_type]', array(
	'default'           => $options['info_content_heading_type'],
	'sanitize_callback' => 'kids_education_pro_sanitize_select'
) );

$wp_customize->add_control( 'kids_education_pro_theme_options[info_content_heading_type]', array(
	'label'           	=> __( 'Display Heading from', 'kids-education-pro' ),
	'section'         	=> 'kids_education_pro_info_content_section',
	'type'            	=> 'select',
	'active_callback' 	=> 'kids_education_pro_is_info_content_as_page',
	'choices'         	=> array(
		'info_content_headline_from_title'   => __( 'Page Title','kids-education-pro'),
		'info_content_headline_from_content' => __( 'Page Content', 'kids-education-pro')	
	)
) );

// Add load more text setting and control.
$wp_customize->add_setting( 'kids_education_pro_theme_options[info_content_learn_more_text]', array(
	'default'           => $options['info_content_learn_more_text'],
	'sanitize_callback' => 'sanitize_text_field'
) );

$wp_customize->add_control( 'kids_education_pro_theme_options[info_content_learn_more_text]', array(
	'label'           	=> __( 'Learn more text', 'kids-education-pro' ),
	'section'         	=> 'kids_education_pro_info_content_section',
	'active_callback' 	=> 'kids_education_pro_is_info_content_as_page',
) );

// Add background property setting and control.
$wp_customize->add_setting( 'kids_education_pro_theme_options[info_content_background_property]', array(
	'default'           => $options['info_content_background_property'],
	'sanitize_callback' => 'kids_education_pro_sanitize_select'
) );

$wp_customize->add_control( 'kids_education_pro_theme_options[info_content_background_property]', array(
	'label'           	=> __( 'Select background property', 'kids-education-pro' ),
	'section'         	=> 'kids_education_pro_info_content_section',
	'active_callback' 	=> 'kids_education_pro_is_info_content_as_page',
	'type'				=> 'select',
	'choices'			=> array(
		'background_image' => __( 'Background Image', 'kids-education-pro' ),
		'background_color' => __( 'Background Color', 'kids-education-pro' ), 
	)
) );

// Add background image setting and control.
$wp_customize->add_setting( 'kids_education_pro_theme_options[info_content_background_image]', array(
	'default'           => $options['info_content_background_image'],
	'sanitize_callback' => 'esc_url_raw'
) );

$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'kids_education_pro_theme_options[info_content_background_image]',
    array(
		'label'           => __( 'Upload a background image', 'kids-education-pro' ),
		'description'     => __( 'Recommended background image size is 1920x420 px', 'kids-education-pro' ),
		'section'         => 'kids_education_pro_info_content_section',
		'active_callback' => 'kids_education_pro_is_info_content_background_property_image',
   )
));

// Add background color setting and control.
$wp_customize->add_setting( 'kids_education_pro_theme_options[info_content_background_color]', array(
	'default'           => $options['info_content_background_color'],
	'sanitize_callback' => 'sanitize_hex_color'
) );

$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'kids_education_pro_theme_options[info_content_background_color]', array(
	'label'        => __( 'Background Color', 'kids-education-pro' ),
	'section'    => 'kids_education_pro_info_content_section',
	'active_callback' => 'kids_education_pro_is_info_content_background_property_color',
) ) );