<?php
/**
 * Kids Education Pro Recent Customizer options
 *
 * @package Theme Palace
 * @subpackage Kids Education Pro
 * @since Kids Education Pro 1.0
 */


// Add recent enable section
$wp_customize->add_section( 'kids_education_pro_recent', array(
	'title'             => __('Recent','kids-education-pro'),
	'description'       => __( 'Recent section options.', 'kids-education-pro' ),
	'panel'             => 'kids_education_pro_sections_panel'
) );

// Add recent enable setting and control.
$wp_customize->add_setting( 'kids_education_pro_theme_options[recent_enable]', array(
	'default'           => $options['recent_enable'],
	'sanitize_callback' => 'kids_education_pro_sanitize_select'
) );

$wp_customize->add_control( 'kids_education_pro_theme_options[recent_enable]', array(
	'label'             => __( 'Enable on', 'kids-education-pro' ),
	'section'           => 'kids_education_pro_recent',
	'type'              => 'select',
	'choices'           => kids_education_pro_enable_disable_options()
) );

// Add recent title setting and control.
$wp_customize->add_setting( 'kids_education_pro_theme_options[recent_title]', array(
	'default'           => $options['recent_title'],
	'transport'         => 'postMessage',
	'sanitize_callback' => 'sanitize_text_field'
) );

$wp_customize->add_control( 'kids_education_pro_theme_options[recent_title]', array(
	'label'             => __( 'Title', 'kids-education-pro' ),
	'section'           => 'kids_education_pro_recent',
	'type'              => 'text',
	'active_callback'	=> 'kids_education_pro_is_recent_section_active',
) );


// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
	$wp_customize->selective_refresh->add_partial( 'kids_education_pro_theme_options[recent_title]', array(
		'selector'            => '#recent-classes-slider h2.entry-title',
		'render_callback'     => 'kids_education_pro_customize_partial_recent_title',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
	) );
}

// Add recent description setting and control.
$wp_customize->add_setting( 'kids_education_pro_theme_options[recent_description]', array(
	'default'           => $options['recent_description'],
	'sanitize_callback' => 'esc_textarea'
) );

$wp_customize->add_control( 'kids_education_pro_theme_options[recent_description]', array(
	'label'             => __( 'Description', 'kids-education-pro' ),
	'section'           => 'kids_education_pro_recent',
	'type'              => 'textarea',
	'active_callback'	=> 'kids_education_pro_is_recent_section_active',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
	$wp_customize->selective_refresh->add_partial( 'kids_education_pro_theme_options[recent_description]', array(
		'selector'            => '#recent-classes-slider .entry-header p.sub-title',
		'render_callback'     => 'kids_education_pro_customize_partial_recent_description',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
	) );
}

// Add no of recent content type setting and control.
$wp_customize->add_setting( 'kids_education_pro_theme_options[recent_content_type]', array(
	'default'           => $options['recent_content_type'],
	'sanitize_callback' => 'kids_education_pro_sanitize_select',
) );

$wp_customize->add_control( 'kids_education_pro_theme_options[recent_content_type]', array(
	'label'             => __( 'Content Type', 'kids-education-pro' ),
	'section'           => 'kids_education_pro_recent',
	'type'              => 'select',
	'choices'			=> kids_education_pro_recent_content_type(),
	'active_callback'	=> 'kids_education_pro_is_recent_section_active',
) );

// Add layout option setting and control.
$wp_customize->add_setting( 'kids_education_pro_theme_options[recent_visible_no_of_slides]', array(
	'default'           => $options['recent_visible_no_of_slides'],
	'sanitize_callback' => 'kids_education_pro_sanitize_select',
) );

$wp_customize->add_control( 'kids_education_pro_theme_options[recent_visible_no_of_slides]', array(
	'label'             => __( 'No of visible slides', 'kids-education-pro' ),
	'section'           => 'kids_education_pro_recent',
	'type'              => 'select',
	'choices'		=> array (
		'3'			=> __( 'Three', 'kids-education-pro'),
		'4'			=> __( 'Four', 'kids-education-pro' )
	),
	'active_callback'	=> 'kids_education_pro_is_recent_section_active',
) );

// Add no of recent content setting and control.
$wp_customize->add_setting( 'kids_education_pro_theme_options[recent_count]', array(
	'default'           => $options['recent_count'],
	'sanitize_callback' => 'absint',
) );

$wp_customize->add_control( 'kids_education_pro_theme_options[recent_count]', array(
	'label'             => __( 'No of content', 'kids-education-pro' ),
	'section'           => 'kids_education_pro_recent',
	'type'              => 'number',
	'input_attrs'		=> array (
		'min'	=> 3,
		'max'	=> 9,
		'style'	=> 'width:100px'
		),
	'active_callback'	=> 'kids_education_pro_is_recent_section_active',
) );

// Add recent slide dragable setting and control.
$wp_customize->add_setting( 'kids_education_pro_theme_options[recent_dragable]', array(
	'default'           => $options['recent_dragable'],
	'sanitize_callback' => 'kids_education_pro_sanitize_checkbox'
) );

$wp_customize->add_control( 'kids_education_pro_theme_options[recent_dragable]', array(
	'label'             => __( 'Enable Slider Dragable', 'kids-education-pro' ),
	'section'           => 'kids_education_pro_recent',
	'type'              => 'checkbox',
	'active_callback'	=> 'kids_education_pro_is_recent_section_active',
) );

// Add recent slide pager setting and control.
$wp_customize->add_setting( 'kids_education_pro_theme_options[recent_pager]', array(
	'default'           => $options['recent_pager'],
	'sanitize_callback' => 'kids_education_pro_sanitize_checkbox'
) );

$wp_customize->add_control( 'kids_education_pro_theme_options[recent_pager]', array(
	'label'             => __( 'Enable Slider Pager', 'kids-education-pro' ),
	'section'           => 'kids_education_pro_recent',
	'type'              => 'checkbox',
	'active_callback'	=> 'kids_education_pro_is_recent_section_active',
) );

// Add recent slide pause on hover setting and control.
$wp_customize->add_setting( 'kids_education_pro_theme_options[recent_pauseonhover]', array(
	'default'           => $options['recent_pauseonhover'],
	'sanitize_callback' => 'kids_education_pro_sanitize_checkbox'
) );

$wp_customize->add_control( 'kids_education_pro_theme_options[recent_pauseonhover]', array(
	'label'             => __( 'Enable Pause on Hover', 'kids-education-pro' ),
	'section'           => 'kids_education_pro_recent',
	'type'              => 'checkbox',
	'active_callback'	=> 'kids_education_pro_is_recent_section_active',
) );

// Add background property setting and control.
$wp_customize->add_setting( 'kids_education_pro_theme_options[recent_background_property]', array(
	'default'           => $options['recent_background_property'],
	'sanitize_callback' => 'kids_education_pro_sanitize_select'
) );

$wp_customize->add_control( 'kids_education_pro_theme_options[recent_background_property]', array(
	'label'           	=> __( 'Select background property', 'kids-education-pro' ),
	'section'         	=> 'kids_education_pro_recent',
	'active_callback' 	=> 'kids_education_pro_is_recent_section_active',
	'type'				=> 'select',
	'choices'			=> array(
		'background_image' => __( 'Background Image', 'kids-education-pro' ),
		'background_color' => __( 'Background Color', 'kids-education-pro' ), 
	)
) );

// Add background image setting and control.
$wp_customize->add_setting( 'kids_education_pro_theme_options[recent_background_image]', array(
	'default'           => $options['recent_background_image'],
	'sanitize_callback' => 'esc_url_raw'
) );

$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'kids_education_pro_theme_options[recent_background_image]',
    array(
		'label'           => __( 'Upload a background image', 'kids-education-pro' ),
		'description'     => __( 'Recommended background image size is 1920x420 px', 'kids-education-pro' ),
		'section'         => 'kids_education_pro_recent',
		'active_callback' => 'kids_education_pro_is_recent_section_background_property_image',
   )
));

// Add background color setting and control.
$wp_customize->add_setting( 'kids_education_pro_theme_options[recent_background_color]', array(
	'default'           => $options['recent_background_color'],
	'sanitize_callback' => 'sanitize_hex_color'
) );

$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'kids_education_pro_theme_options[recent_background_color]', array(
	'label'        => __( 'Background Color', 'kids-education-pro' ),
	'section'    => 'kids_education_pro_recent',
	'active_callback' => 'kids_education_pro_is_recent_section_background_property_color',
) ) );