<?php
/**
 * category_blog section
 *
 * This is the template for the content of category_blog section
 *
 * @package Theme Palace
 * @subpackage Kids Education Pro
 * @since Kids Education Pro 1.0
 */
if ( ! function_exists( 'kids_education_pro_add_category_blog_section' ) ) :
  /**
   * Add category_blog section
   *
   *@since Kids Education Pro 1.0
   */
  function kids_education_pro_add_category_blog_section() {

    // Check if category_blog is enabled on frontpage
    $category_blog_enable = apply_filters( 'kids_education_pro_section_status', true, 'category_blog_enable' );
    if ( true !== $category_blog_enable ) {
      return false;
    }

    // Get category_blog section details
    $section_details = array();
    $section_details = apply_filters( 'kids_education_pro_filter_category_blog_section_details', $section_details );

    if ( empty( $section_details ) ) {
      return;
    }

    // Render category_blog section now.
    kids_education_pro_render_category_blog_section( $section_details );
  }
endif;
add_action( 'kids_education_pro_primary_content_footer', 'kids_education_pro_add_category_blog_section', 10 );


if ( ! function_exists( 'kids_education_pro_get_category_blog_section_details' ) ) :
  /**
   * category_blog section details.
   *
   * @since Kids Education Pro 1.0
   * @param array $input category_blog section details.
   */
  function kids_education_pro_get_category_blog_section_details( $input ) {
    $options = kids_education_pro_get_theme_options();

    // category_blog type
    $category_blog_content_type = $options['category_blog_content_type'];
    $content_layout             = !empty( $options['category_blog_section_layout'] ) ? $options['category_blog_section_layout'] : 'two-columns'; // check category blog layout
    $no_of_demo_post            = ( 'three-columns' == $content_layout ) ? 3 : 4; 

    $content = array();
    switch ( $category_blog_content_type ) {
      case 'demo':
        for ( $i=1; $i<=$no_of_demo_post; $i++ ) {
          $content[$i]['img_array'][0] = get_template_directory_uri() . '/assets/uploads/blog-0'.$i.'.jpg';
          $content[$i]['url']          = '#';
          $content[$i]['title']        =__( 'Aenean sollicitudin, lorem', 'kids-education-pro' );
          $content[$i]['excerpt']      = __( 'Proin gravida nibh vel velit auctor aliquet. Aenean sollicitudin, lorem quis bibendum auctor, nisi elit consequat ipsum, nec sagittis sem nibh id eli.', 'kids-education-pro' );
          $content[$i]['alt']          = __( 'category_blog Image', 'kids-education-pro' );
          $content[$i]['date']         = __( 'Dec 18, 2016', 'kids-education-pro' );
          $content[$i]['date_link']    = '#';
          $content[$i]['gmt_time']     = __( '2016-12-21T10:00:09+00:00', 'kids-education-pro' );
          $content[$i]['likes']        = __( '200', 'kids-education-pro' );
          $content[$i]['comment']      = __( '04', 'kids-education-pro' );
        }
      break;

      case 'category':
        $cat_ids = '';
        if ( !empty( $options['category_blog_content_category'] ) ) {
            $cat_ids = $options['category_blog_content_category'];
        }
        
        // Bail if no valid pages are selected.
        if ( empty( $cat_ids ) ) {
            return $input;
        }
        $args = array(
            'post_type'      => 'post',
            'category__in'   => $cat_ids,
            'posts_per_page' => absint( $options['category_blog_count'] ),
            'orderby'        => 'ASC',
        );
      break;

      default:
      break;
    }

    if ( 'demo' != $category_blog_content_type ) {
      // Fetch posts.
      $posts = get_posts( $args );

      if ( ! empty( $posts ) ) {

          $i = 1;
          foreach ( $posts as $key => $post ) {

            $page_id = $post->ID;
            $img_array = null;

            if ( has_post_thumbnail( $page_id ) ) {
                $img_array = wp_get_attachment_image_src( get_post_thumbnail_id( $post->ID ), 'kids-education-pro-blog-images' );
            } else {
                $img_array[0] =  get_template_directory_uri().'/assets/uploads/no-featured-image-175x230.jpg';
            }

            if ( isset( $img_array ) ) {
              $content[$i]['img_array'] = $img_array;
            }

            $year  = get_the_time('Y', $page_id );
            $month = get_the_time('m', $page_id );
            $day   = get_the_time('d', $page_id );

            $content[$i]['url']       = get_permalink( $page_id );
            $content[$i]['title']     = get_the_title( $page_id );
            $content[$i]['excerpt']   = kids_education_pro_trim_content( 15, $post  );
            $content[$i]['alt']       = get_the_title( $page_id );
            $content[$i]['date']      = get_the_date( '', $page_id );
            $content[$i]['date_link'] = get_day_link( $year, $month, $day );
            $content[$i]['gmt_time']  = $post->post_date_gmt;
            $content[$i]['likes']     = function_exists( 'tp_education_like_button' )  ? tp_education_like_button( $page_id ) : '';
            $content[$i]['comment']   = get_comments_number( $page_id );

            $i++;
          }
      }
    }

    if ( ! empty( $content ) ) {
      $input = $content;
    }
    return $input;
  }
endif;
// category_blog section content details.
add_filter( 'kids_education_pro_filter_category_blog_section_details', 'kids_education_pro_get_category_blog_section_details' );


if ( ! function_exists( 'kids_education_pro_render_category_blog_section' ) ) :
  /**
   * Start category_blog section
   *
   * @return string category_blog content
   * @since Kids Education Pro 1.0
   *
   */
   function kids_education_pro_render_category_blog_section( $content_details = array() ) {
        $options          = kids_education_pro_get_theme_options();
        $blog_class       = ( ! $options['enable_frontpage_content'] ) ? 'move-section-up' : '';

        if ( empty( $content_details ) ) {
          return;
        } 
        $blog_content_type =  !empty(  $options['category_blog_content_type'] ) ? $options['category_blog_content_type'] : 'demo';
        $blog_title        = !empty( $options['category_blog_title'] ) ? $options['category_blog_title'] : '';
        $blog_description  = !empty( $options['category_blog_description'] ) ? $options['category_blog_description'] : '';
        $blog_layout       = !empty( $options['category_blog_section_layout'] ) ? $options['category_blog_section_layout'] : 'two-columns';

        $background_property = $options['category_blog_background_property'];
        $background_css      = !empty( $options['category_blog_background_image'] ) ? 'style="background-image:url('.  esc_url( $options['category_blog_background_image'] ) .')"' : '';

        if( 'background_color' == $background_property ){
          $background_css = !empty( $options['category_blog_background_color'] ) ? 'style="background-color:'.  esc_attr( $options['category_blog_background_color'] ) .'"' : '';
        }

        ?>

        <section id="blog" class="page-section background-image-properties os-animation <?php echo esc_attr(  $blog_class ); ?>" data-os-animation="fadeIn" <?php echo $background_css; ?>>
	        <div class="container">
	        <?php if( !empty( $blog_title ) || !empty( $blog_description ) ) : ?>
	         	<header class="entry-header">
	        <?php if( !empty( $blog_title )){ ?>
	            <h2 class="entry-title"><?php echo esc_html( $blog_title ); ?></h2>
	        <?php }
	          if( !empty( $blog_description ) ){ ?>
	            <p class="sub-title"><?php echo esc_html( $blog_description ); ?></p>
	        <?php } ?>
	          	</header><!-- .entry-header -->
	        <?php endif; ?>

				<div class="entry-content <?php echo esc_attr( $blog_layout ); ?>">

				<?php foreach ( $content_details as $content_detail ): ?>
					<div class="column-wrapper has-post-thumbnail">
						<div class="blog-wrapper">
							<div class="blog-image">
								<a href="<?php echo esc_url( $content_detail['url'] ); ?>" class="post-thumbnail"><img src="<?php echo esc_url( $content_detail['img_array'][0] ); ?>" alt="<?php echo esc_html( $content_detail['title'] );?>"></a>
							</div><!-- .blog-image -->

							<div class="blog-contents">
								<h6 class="blog-title"><a href="<?php echo esc_url( $content_detail['url'] );?>"><?php echo esc_html( $content_detail['title'] );?></a></h6>
								<p class="entry-meta">
								  	<span class="posted-on">
								    	<span class="screen-reader-text"><?php _e( 'Posted on', 'kids-education-pro' ); ?></span>
								    	<a href="<?php echo esc_url($content_detail['date_link'] );?>">
								      		<time class="entry-date published" datetime="<?php echo esc_attr( $content_detail['gmt_time'] );?>"><?php echo esc_html( $content_detail['date'] );?></time>
								      		<time class="updated" datetime="<?php echo esc_attr( $content_detail['gmt_time'] );?>"><?php echo esc_html( $content_detail['date'] ); ?></time>
								    	</a>
								  	</span><!-- .posted-on -->
								  	<?php if ( 'demo' == $blog_content_type ){
								        echo '<span class="likes"><a href="#"><i class="fa fa-likes"></i>'. absint( $content_detail['likes'] ) .'</a></span>';
								  	} else{
								    	echo wp_kses_post( $content_detail['likes'] );
								  	}?>

								  	<span class="comments-links">
								    	<span class="screen-reader-text"><?php _e( 'Comments', 'kids-education-pro' ); ?></span> 
								 	<?php echo absint( $content_detail['comment'] );?>
								  	</span><!-- .comments-links -->
								</p><!-- .entry-meta -->

								<p><?php echo esc_html( $content_detail['excerpt']);?></p>
								<a href="<?php echo esc_url( $content_detail['url'] ); ?>" class="read-more"><?php echo esc_html( $options['read_more_text'] ); ?></a>
							</div><!-- .blog-contents -->
						</div><!-- .blog-wrapper -->
					</div><!-- .column-wrapper -->
				<?php
				endforeach;
				?>

				</div><!-- .entry-content -->
	        </div><!-- .container -->
      	</section><!-- #blog -->
    </div><!--.site-content-->

    <div class="footer-divider">
      <img src="<?php echo get_template_directory_uri();?>/assets/uploads/footer-divider.png" alt="<?php _e('Footer divider', 'kids-education-pro' ); ?>">
    </div><!-- .footer-divider -->
<?php 
    }
endif;