<?php
/**
 * Kids Education options
 *
 * @package Theme Palace
 * @subpackage Kids Education Pro
 * @since Kids Education Pro 1.0
 */

/**
 * Returns list of typography
 * @return array font styles
 */
function kids_education_pro_typography_options(){

    $choices = array(
      'poppins-courgette' => __( 'POPPINS AND COURGETTE FONT', 'kids-education-pro' ),
      'roboto-monsterrat' => __( 'ROBOTO AND MONTSERRAT FONT', 'kids-education-pro' ),
      'raleway-poppins'   => __( 'RALEWAY AND POPPINS FONT', 'kids-education-pro' ),
      'courgette-roboto'  => __( 'COURGETTE AND ROBOTO FONT', 'kids-education-pro' ),
      'default'           => __( 'DEFAULT', 'kids-education-pro' ),
      'pacifico'          => __( 'PACIFICO FONT', 'kids-education-pro' ),
      'indie-flower'      => __( 'INDIE FLOWER FONT', 'kids-education-pro' ),
      'atma'              => __( 'ATMA FONT', 'kids-education-pro' )
    );
    $output = apply_filters( 'kids_education_pro_typography_options', $choices );
    if ( ! empty( $output ) ) {
      ksort( $output );
    }
    return $output;

}

/**
 * Site Layout
 * @return array site layout options
 */
function kids_education_pro_site_layout() {
  $kids_education_pro_site_layout = array(
    'wide'  => __( 'Wide', 'kids-education-pro' ),
    'boxed' => __( 'Boxed', 'kids-education-pro' ),
  );

  $output = apply_filters( 'kids_education_pro_site_layout', $kids_education_pro_site_layout );

  return $output;
}

/**
 * Sidebar position
 * @return array Sidbar positions
 */
function kids_education_pro_sidebar_position() {
  $kids_education_pro_sidebar_position = array(
    'right-sidebar' => __( 'Right', 'kids-education-pro' ),
    'left-sidebar'  => __( 'Left', 'kids-education-pro' ),
    'no-sidebar'    => __( 'No Sidebar', 'kids-education-pro' ),
  );

  $output = apply_filters( 'kids_education_pro_sidebar_position', $kids_education_pro_sidebar_position );

  return $output;
}

/**
 * Header image options
 * @return array Header image options
 */
function kids_education_pro_header_image() {
  $kids_education_pro_header_image = array(
    'enable' => __( 'Enable( Featured Image )', 'kids-education-pro' ),
    '' => __( 'Default ( Customizer Header Image )', 'kids-education-pro' ),
    'disable'  => __( 'Disable', 'kids-education-pro' ),
  );

  $output = apply_filters( 'kids_education_pro_header_image', $kids_education_pro_header_image );

  return $output;
}

/**
 * Pagination
 * @return array site pagination options
 */
function kids_education_pro_pagination_options() {
  $kids_education_pro_pagination_options = array(
    'numeric'         => __( 'Numeric', 'kids-education-pro' ),
    'default'         => __( 'Default(Older/Newer)', 'kids-education-pro' ),
    'infinite-scroll' => __( 'Infinite-Scroll', 'kids-education-pro' ),
    'infinite-click'  => __( 'Infinite-Click', 'kids-education-pro' ),
  );

  $output = apply_filters( 'kids_education_pro_pagination_options', $kids_education_pro_pagination_options );

  return $output;
}

/**
 * Slider
 * @return array slider options
 */
function kids_education_pro_enable_disable_options() {
  $kids_education_pro_enable_disable_options = array(
    'static-frontpage'  => __( 'Static Frontpage', 'kids-education-pro' ),
    'disabled'          => __( 'Disabled', 'kids-education-pro' ),
  );

  $output = apply_filters( 'kids_education_pro_enable_disable_options', $kids_education_pro_enable_disable_options );

  return $output;
}

/**
 * Slider effects
 * @return array Slider effects
 */
function kids_education_pro_slider_effect() {
  $kids_education_pro_slider_effect = array(
    'cubic-bezier(0.680, 0, 0.265, 1)'            => __( 'Default', 'kids-education-pro' ),
    'fade'                                        => __( 'Fade', 'kids-education-pro' ),
    'cubic-bezier(0.250, 0.250, 0.750, 0.750)'    => __( 'Linear', 'kids-education-pro' ),
    'cubic-bezier(0.250, 0.100, 0.250, 1.000)'    => __( 'Ease', 'kids-education-pro' ),
    'cubic-bezier(0.950, 0.050, 0.795, 0.035)'    => __( 'cubic', 'kids-education-pro' ),
    'cubic-bezier(0.600, -0.280, 0.735, 0.045)'   => __( 'Ease In Back', 'kids-education-pro' ),
    'cubic-bezier(0.785, 0.135, 0.150, 0.860)'    => __( 'EaseInOutCirc', 'kids-education-pro' ),
    'cubic-bezier(0.680, -0.550, 0.265, 1.550)'   => __( 'EaseInOutBack', 'kids-education-pro' ),
  );

  $output =  apply_filters( 'kids_education_pro_slider_effect', $kids_education_pro_slider_effect );

  // Sort array in ascending order, according to the key:
  if ( ! empty( $output ) ) {
    ksort( $output );
  }

  return $output;
}

/**
 * Returns list for recent section content type
 * @return array content type
 */
function kids_education_pro_recent_content_type(){

    $choices        = array(
      'demo'        => __( 'Demo', 'kids-education-pro' ),
      'post'        => __( 'Post', 'kids-education-pro' ),
    );
    $custom_choices = array();
    if ( class_exists( 'TP_Education' ) ) {
      $custom_choices = array(
        'class'       => __( 'Class', 'kids-education-pro' ),
        'course'      => __( 'Course', 'kids-education-pro' ),
        'event'       => __( 'Event', 'kids-education-pro' ),
        'excursion'   => __( 'Excursion', 'kids-education-pro' ),
      );
    }
    $choices = array_merge( $choices, $custom_choices );
    $output = apply_filters( 'kids_education_pro_recent_content_type', $choices );
    if ( ! empty( $output ) ) {
      ksort( $output );
    }
    return $output;

}

/**
 * Returns list for testimonial section content type
 * @return array content type
 */
function kids_education_pro_testimonial_content_type(){

    $choices        = array(
      'demo'        => __( 'Demo', 'kids-education-pro' ),
    );
    $custom_choices = array();
    if ( class_exists( 'TP_Education' ) ) {
      $custom_choices = array(
        'post'       => __( 'Testimonial Posts', 'kids-education-pro' ),
      );
    }
    $choices = array_merge( $choices, $custom_choices );
    $output = apply_filters( 'kids_education_pro_recent_content_type', $choices );
    if ( ! empty( $output ) ) {
      ksort( $output );
    }
    return $output;

}

/**
 * Returns list for team section content type
 * @return array content type
 */
function kids_education_pro_team_content_type(){

    $choices        = array(
      'demo'        => __( 'Demo', 'kids-education-pro' ),
    );
    $custom_choices = array();
    if ( class_exists( 'TP_Education' ) ) {
      $custom_choices = array(
        'post'       => __( 'Team Posts', 'kids-education-pro' ),
        'category'   => __( 'Team Category', 'kids-education-pro' ),
      );
    }
    $choices = array_merge( $choices, $custom_choices );
    $output = apply_filters( 'kids_education_pro_recent_content_type', $choices );
    if ( ! empty( $output ) ) {
      ksort( $output );
    }
    return $output;

}